@@ -312,21 +312,6 @@ class Agent(Insight, Channel, Catalog, Dataset):
         response.raise_for_status()
         r = response.json()
 
-    def _load_dataset(self, dataset_id):
-
-        s = requests.Session()
-        s.keep_alive = False
-        retries = Retry(total=5, backoff_factor=1, status_forcelist=[502, 503, 504])
-        s.mount('https://', HTTPAdapter(max_retries=retries))
-
-        authentication_url = self._base_url_askdata + '/smartdataset/datasets/' + dataset_id + '/grid/data'
-        logging.info("AUTH URL {}".format(authentication_url))
-
-        headers = {"Authorization": "Bearer" + " " + self._token}
-        response = s.get(url=authentication_url, headers=headers)
-        response.raise_for_status()
-        r = response.json()
-        return pd.DataFrame(r['payload']['data'])
 
     def get_dataset_by_slug(self, agent_slug, slug: str):
         s = requests.Session()
