@@ -49,6 +49,49 @@ class Insight_Definition:
             self.smart_insight_url = url_list['BASE_URL_INSIGHT_PROD']
             self.app_url = "https://app.askdata.com"
 
+    def __make_get_request(self, url):
+        s = requests.Session()
+        s.keep_alive = False
+        retries = Retry(total=5, backoff_factor=1, status_forcelist=[502, 503, 504])
+        s.mount('https://', HTTPAdapter(max_retries=retries))
+
+        headers = {
+            "Content-Type": "application/json",
+            "Authorization": "Bearer" + " " + self._token
+        }
+
+        r = s.get(url=url, headers=headers)
+        r.raise_for_status()
+        return r
+
+    def __make_put_request(self, url, body):
+
+        s = requests.Session()
+        s.keep_alive = False
+        retries = Retry(total=5, backoff_factor=1, status_forcelist=[502, 503, 504])
+        s.mount('https://', HTTPAdapter(max_retries=retries))
+        headers = {
+            "Content-Type": "application/json",
+            "Authorization": "Bearer" + " " + self._token
+        }
+        r = s.put(url=url, json=body, headers=headers)
+        r.raise_for_status()
+        return r
+
+    def __make_post_request(self, url, body):
+        s = requests.Session()
+        s.keep_alive = False
+        retries = Retry(total=5, backoff_factor=1, status_forcelist=[502, 503, 504])
+        s.mount('https://', HTTPAdapter(max_retries=retries))
+
+        headers = {
+            "Content-Type": "application/json",
+            "Authorization": "Bearer" + " " + self._token
+        }
+
+        r = s.post(url=url, json=body, headers=headers)
+        r.raise_for_status()
+        return r
 
     def add_skin(self, skin_code:str):
         body = {
@@ -61,19 +104,7 @@ class Insight_Definition:
         }
 
         url = self.smart_insight_url+"/definitions/"+self.definition_id
-
-        s = requests.Session()
-        s.keep_alive = False
-        retries = Retry(total=5, backoff_factor=1, status_forcelist=[502, 503, 504])
-        s.mount('https://', HTTPAdapter(max_retries=retries))
-
-        headers = {
-            "Content-Type": "application/json",
-            "Authorization": "Bearer" + " " + self._token
-        }
-
-        r = s.put(url=url, json=body, headers=headers)
-        r.raise_for_status()
+        r = self.__make_put_request(url, body)
         self.components = r.json()["components"]
 
     def add_widget(self, widget_type: str, query_ids:list=[], settings:dict={}, values:dict={}, texts:dict={}, charts:list=[]):
@@ -91,19 +122,16 @@ class Insight_Definition:
 
         settings = {}
         for field in field_codes.keys():
-            found = False
             for column in columns:
                 if(column["code"] in field_codes[field]):
                     for query in query_ids:
                         if(str(field_codes[field]).startswith(query)):
                            if(str(column["id"]).startswith(query)):
                                settings[field + "_id"] = column["id"]
-                               found = True
                                break
                            else:
                                continue
                         else:
-                            found = True
                             settings[field + "_id"] = column["id"]
                             break
 
@@ -124,36 +152,14 @@ class Insight_Definition:
             "valid": True,
             "queryComponent": False
         }
-
-        s = requests.Session()
-        s.keep_alive = False
-        retries = Retry(total=5, backoff_factor=1, status_forcelist=[502, 503, 504])
-        s.mount('https://', HTTPAdapter(max_retries=retries))
-
-        headers = {
-            "Content-Type": "application/json",
-            "Authorization": "Bearer" + " " + self._token
-        }
-        r = s.put(url=url, json=body, headers=headers)
-        r.raise_for_status()
+        r = self.__make_put_request(url, body)
         self.components = r.json()["components"]
 
     def __get_columns(self, query_ids) -> list:
 
         url = self.smart_insight_url+"/definitions/"+self.definition_id+"/queries/columns"
         body = {"queryIds": query_ids}
-        s = requests.Session()
-        s.keep_alive = False
-        retries = Retry(total=5, backoff_factor=1, status_forcelist=[502, 503, 504])
-        s.mount('https://', HTTPAdapter(max_retries=retries))
-
-        headers = {
-            "Content-Type": "application/json",
-            "Authorization": "Bearer" + " " + self._token
-        }
-
-        r = s.post(url=url, json=body, headers=headers)
-        r.raise_for_status()
+        r = self.__make_post_request(url, body)
         return r.json()
 
     def display_card_img(self):
@@ -230,19 +236,9 @@ class Insight_Definition:
     def __create_widget(self, position, widget_type):
 
         body = {"type": "widget", "position": position, "widgetType": widget_type}
+        url = self.smart_insight_url + '/definitions/' + self.definition_id + '/components/'
 
-        s = requests.Session()
-        s.keep_alive = False
-        retries = Retry(total=5, backoff_factor=1, status_forcelist=[502, 503, 504])
-        s.mount('https://', HTTPAdapter(max_retries=retries))
-
-        headers = {
-            "Content-Type": "application/json",
-            "Authorization": "Bearer" + " " + self._token
-        }
-        query_url = self.smart_insight_url + '/definitions/' + self.definition_id + '/components/'
-        r = s.post(url=query_url, json=body, headers=headers)
-        r.raise_for_status()
+        r = self.__make_post_request(url, body)
         self.components = r.json()["components"]
         return self.components[position]["id"]
 
@@ -250,18 +246,9 @@ class Insight_Definition:
 
         position = (len(self.components))
         body = {"type": "table", "position": position}
-        s = requests.Session()
-        s.keep_alive = False
-        retries = Retry(total=5, backoff_factor=1, status_forcelist=[502, 503, 504])
-        s.mount('https://', HTTPAdapter(max_retries=retries))
 
-        headers = {
-            "Content-Type": "application/json",
-            "Authorization": "Bearer" + " " + self._token
-        }
-        query_url = self.smart_insight_url + '/definitions/' + self.definition_id + '/components/'
-        r = s.post(url=query_url, json=body, headers=headers)
-        r.raise_for_status()
+        url = self.smart_insight_url + '/definitions/' + self.definition_id + '/components/'
+        r = self.__make_post_request(url, body)
         self.components = r.json()["components"]
 
         if(query != "" and columns!=[]):
@@ -286,19 +273,7 @@ class Insight_Definition:
             "valid":True,
             "queryComponent":False
         }
-
-        s = requests.Session()
-        s.keep_alive = False
-        retries = Retry(total=5, backoff_factor=1, status_forcelist=[502, 503, 504])
-        s.mount('https://', HTTPAdapter(max_retries=retries))
-
-        headers = {
-            "Content-Type": "application/json",
-            "Authorization": "Bearer" + " " + self._token
-        }
-
-        r = s.put(url=url, json=body, headers=headers)
-        r.raise_for_status()
+        r = self.__make_put_request(url, body)
         self.components = r.json()["components"]
 
 
@@ -414,19 +389,7 @@ class Insight_Definition:
             "type": "chart",
             "valid": True
         }
-
-        s = requests.Session()
-        s.keep_alive = False
-        retries = Retry(total=5, backoff_factor=1, status_forcelist=[502, 503, 504])
-        s.mount('https://', HTTPAdapter(max_retries=retries))
-
-        headers = {
-            "Content-Type": "application/json",
-            "Authorization": "Bearer" + " " + self._token
-        }
-
-        r = s.put(url=url, json=body, headers=headers)
-        r.raise_for_status()
+        r = self.__make_put_request(url, body)
         self.components = r.json()["components"]
 
 
@@ -459,19 +422,7 @@ class Insight_Definition:
             "valid":True,
             "queryComponent":False
         }
-
-
-        s = requests.Session()
-        s.keep_alive = False
-        retries = Retry(total=5, backoff_factor=1, status_forcelist=[502, 503, 504])
-        s.mount('https://', HTTPAdapter(max_retries=retries))
-
-        headers = {
-            "Content-Type": "application/json",
-            "Authorization": "Bearer" + " " + self._token
-        }
-        r = s.put(url=url, json=body, headers=headers)
-        r.raise_for_status()
+        r = self.__make_put_request(url, body)
         self.components = r.json()["components"]
 
     def add_data(self, df:pd.DataFrame, parameters_settings:list=[]):
@@ -626,14 +577,7 @@ class Insight_Definition:
 
         url = self.smart_insight_url + "/composed_queries/sdk"
 
-        s = requests.Session()
-        s.keep_alive = False
-        retries = Retry(total=5, backoff_factor=1, status_forcelist=[502, 503, 504])
-        s.mount('https://', HTTPAdapter(max_retries=retries))
-
-        headers = {"Authorization": "Bearer" + " " + self._token}
-        response = s.post(url=url, json=body, headers=headers)
-        response.raise_for_status()
+        response = self.__make_post_request(url, body)
 
         return response.json()
 
@@ -655,17 +599,7 @@ class Insight_Definition:
             "qcId": qc_id
         }
         url = self._base_url_askdata+"/smartinsight/definitions/"+self.definition_id+"/data_queries/"+data_id
-        s = requests.Session()
-        s.keep_alive = False
-        retries = Retry(total=5, backoff_factor=1, status_forcelist=[502, 503, 504])
-        s.mount('https://', HTTPAdapter(max_retries=retries))
-
-        headers = {
-            "Content-Type": "application/json",
-            "Authorization": "Bearer" + " " + self._token
-        }
-        r = s.put(url=url, json=body, headers=headers)
-        r.raise_for_status()
+        r = self.__make_put_request(url, body)
         self.components = r.json()["components"]
 
     def edit_data(self, data_id: str, df: pd.DataFrame, index:bool=False, qc_id=None):
@@ -735,40 +669,14 @@ class Insight_Definition:
                 "pinnedValues": {}
             }
         ]
-        # logging.info("URL: {}".format(url))
-
-        s = requests.Session()
-        s.keep_alive = False
-        retries = Retry(total=5, backoff_factor=1, status_forcelist=[502, 503, 504])
-        s.mount('https://', HTTPAdapter(max_retries=retries))
-
-        headers = {
-            "Content-Type": "application/json",
-            "Authorization": "Bearer" + " " + self._token
-        }
-        r = s.put(url=url, json=body, headers=headers)
-        r.raise_for_status()
-
-
+        self.__make_put_request(url, body)
 
     def edit_data_name(self, data_id, component_name):
         url = self.smart_insight_url+"/definitions/"+self.definition_id+"/data_queries/"+data_id
         body = {
             "name": component_name
         }
-        #logging.info("URL: {}".format(url))
-
-        s = requests.Session()
-        s.keep_alive = False
-        retries = Retry(total=5, backoff_factor=1, status_forcelist=[502, 503, 504])
-        s.mount('https://', HTTPAdapter(max_retries=retries))
-
-        headers = {
-            "Content-Type": "application/json",
-            "Authorization": "Bearer" + " " + self._token
-        }
-        r = s.put(url=url, json=body, headers=headers)
-        r.raise_for_status()
+        r = self.__make_put_request(url, body)
         self.components = r.json()["components"]
 
     def add_cta(self, cta_label, cta_url):
@@ -791,20 +699,7 @@ class Insight_Definition:
             "label":label,
             "link":cta_url
         }
-
-        #logging.info("URL: {}".format(url))
-
-        s = requests.Session()
-        s.keep_alive = False
-        retries = Retry(total=5, backoff_factor=1, status_forcelist=[502, 503, 504])
-        s.mount('https://', HTTPAdapter(max_retries=retries))
-
-        headers = {
-            "Content-Type": "application/json",
-            "Authorization": "Bearer" + " " + self._token
-        }
-        r = s.put(url=url, json=body, headers=headers)
-        r.raise_for_status()
+        r = self.__make_put_request(url, body)
         self.components = r.json()["components"]
 
     def add_compare(self, name, second_item_enabled, query_id_1, measure_1, label_1, description_1,
@@ -838,19 +733,7 @@ class Insight_Definition:
             "secondItemEnabled": second_item_enabled,
             "formatterType":formatter_type
         }
-        #logging.info("URL: {}".format(url))
-
-        s = requests.Session()
-        s.keep_alive = False
-        retries = Retry(total=5, backoff_factor=1, status_forcelist=[502, 503, 504])
-        s.mount('https://', HTTPAdapter(max_retries=retries))
-
-        headers = {
-            "Content-Type": "application/json",
-            "Authorization": "Bearer" + " " + self._token
-        }
-        r = s.put(url=url, json=body, headers=headers)
-        r.raise_for_status()
+        r = self.__make_put_request(url, body)
         self.components = r.json()["components"]
 
 
@@ -876,20 +759,7 @@ class Insight_Definition:
             "valid": True
         }
 
-        #logging.info("URL: {}".format(url))
-
-        s = requests.Session()
-        s.keep_alive = False
-        retries = Retry(total=5, backoff_factor=1, status_forcelist=[502, 503, 504])
-        s.mount('https://', HTTPAdapter(max_retries=retries))
-
-        headers = {
-            "Content-Type": "application/json",
-            "Authorization": "Bearer" + " " + self._token
-        }
-
-        r = s.put(url=url, json=body, headers=headers)
-        r.raise_for_status()
+        r = self.__make_put_request(url, body)
         self.components = r.json()["components"]
 
 
@@ -907,19 +777,7 @@ class Insight_Definition:
         body = {
             "html": code
         }
-
-        s = requests.Session()
-        s.keep_alive = False
-        retries = Retry(total=5, backoff_factor=1, status_forcelist=[502, 503, 504])
-        s.mount('https://', HTTPAdapter(max_retries=retries))
-
-        headers = {
-            "Content-Type": "application/json",
-            "Authorization": "Bearer" + " " + self._token
-        }
-
-        r = s.put(url=url, json=body, headers=headers)
-        r.raise_for_status()
+        r = self.__make_put_request(url, body)
         self.components = r.json()["components"]
 
 
@@ -937,19 +795,7 @@ class Insight_Definition:
         body = {
             "script": script
         }
-
-        s = requests.Session()
-        s.keep_alive = False
-        retries = Retry(total=5, backoff_factor=1, status_forcelist=[502, 503, 504])
-        s.mount('https://', HTTPAdapter(max_retries=retries))
-
-        headers = {
-            "Content-Type": "application/json",
-            "Authorization": "Bearer" + " " + self._token
-        }
-
-        r = s.put(url=url, json=body, headers=headers)
-        r.raise_for_status()
+        r = self.__make_put_request(url, body)
         self.components = r.json()["components"]
 
     def add_map(self):
@@ -995,19 +841,7 @@ class Insight_Definition:
         }
 
         url = self.smart_insight_url+"/definitions/"+self.definition_id+"/images/"+image_id
-
-        s = requests.Session()
-        s.keep_alive = False
-        retries = Retry(total=5, backoff_factor=1, status_forcelist=[502, 503, 504])
-        s.mount('https://', HTTPAdapter(max_retries=retries))
-
-        headers = {
-            "Content-Type": "application/json",
-            "Authorization": "Bearer" + " " + self._token
-        }
-
-        r = s.put(url=url, json=body, headers=headers)
-        r.raise_for_status()
+        r = self.__make_put_request(url, body)
         self.components = r.json()["components"]
 
     def add_sql_query(self, query_sql, dataset_slug, is_native = False):
@@ -1061,31 +895,18 @@ class Insight_Definition:
             "sql": query_sql,
         }
 
-        s = requests.Session()
-        s.keep_alive = False
-        retries = Retry(total=5, backoff_factor=1, status_forcelist=[502, 503, 504])
-        s.mount('https://', HTTPAdapter(max_retries=retries))
-
-        headers = {
-            "Content-Type": "application/json",
-            "Authorization": "Bearer" + " " + self._token
-        }
-
-        r = s.put(url=url, json=body, headers=headers)
-        r.raise_for_status()
-
+        r = self.__make_put_request(url, body)
         self.components = r.json()["components"]
 
-        hasResultSet = True
+        has_result_set = True
 
         for component in r.json()["components"]:
             if component["id"] == sql_id:
-                if component["preview"] == []:
-                    hasResultSet = False
-                elif component["preview"][0]["details"]["rows"] == []:
-                    hasResultSet = False
+                if component["preview"] == [] or component["preview"][0]["details"]["rows"] == []:
+                    has_result_set = False
 
-        return sql_id , hasResultSet
+
+        return sql_id , has_result_set
 
 
     def delete(self):
@@ -1129,7 +950,7 @@ class Insight_Definition:
 
         try:
             dataset_id = r["dataset"]["id"]
-        except:
+        except KeyError:
             logging.error("DATASET NOT FOUND")
             return
 
@@ -1252,18 +1073,7 @@ class Insight_Definition:
 
         get_url = self._base_url_askdata+"/smartbot/agents/"+self.agent_id
 
-        s = requests.Session()
-        s.keep_alive = False
-        retries = Retry(total=5, backoff_factor=1, status_forcelist=[502, 503, 504])
-        s.mount('https://', HTTPAdapter(max_retries=retries))
-
-        headers = {
-            "Content-Type": "application/json",
-            "Authorization": "Bearer" + " " + self._token
-        }
-
-        r = s.get(url=get_url, headers=headers)
-        r.raise_for_status()
+        r = self.__make_get_request(get_url)
 
         agent_slug = r.json()["slug"]
 
@@ -1277,18 +1087,8 @@ class Insight_Definition:
 
         get_url = self._base_url_askdata+"/smartbot/share/principals?q="+admin_email
 
-        s = requests.Session()
-        s.keep_alive = False
-        retries = Retry(total=5, backoff_factor=1, status_forcelist=[502, 503, 504])
-        s.mount('https://', HTTPAdapter(max_retries=retries))
+        r = self.__make_get_request(get_url)
 
-        headers = {
-            "Content-Type": "application/json",
-            "Authorization": "Bearer" + " " + self._token
-        }
-
-        r = s.get(url=get_url, headers=headers)
-        r.raise_for_status()
         if(r.json()!=[]):
             for user in r.json():
                 body = {
@@ -1298,18 +1098,9 @@ class Insight_Definition:
                 try:
                     url = self.smart_insight_url+"/insights/"+self.definition_id+"/users"
 
-                    s = requests.Session()
-                    s.keep_alive = False
-                    retries = Retry(total=5, backoff_factor=1, status_forcelist=[502, 503, 504])
-                    s.mount('https://', HTTPAdapter(max_retries=retries))
+                    self.__make_post_request(url, body)
 
-                    headers = {
-                        "Content-Type": "application/json",
-                        "Authorization": "Bearer" + " " + self._token
-                    }
-                    r = s.post(url=url, json=body, headers=headers)
-                    r.raise_for_status()
-                except:
+                except Exception:
                     logging.info("User {} can't be invited to channel, make sure the email is associated to an Askdata user".format(admin_email))
 
         else:
@@ -1320,18 +1111,7 @@ class Insight_Definition:
 
         get_url = self._base_url_askdata+"/smartbot/share/principals?q="+follower_email
 
-        s = requests.Session()
-        s.keep_alive = False
-        retries = Retry(total=5, backoff_factor=1, status_forcelist=[502, 503, 504])
-        s.mount('https://', HTTPAdapter(max_retries=retries))
-
-        headers = {
-            "Content-Type": "application/json",
-            "Authorization": "Bearer" + " " + self._token
-        }
-
-        r = s.get(url=get_url, headers=headers)
-        r.raise_for_status()
+        r = self.__make_get_request(get_url)
         if(r.json()!=[]):
             for user in r.json():
                 body = {
@@ -1341,19 +1121,7 @@ class Insight_Definition:
                 try:
                     url = self.smart_insight_url+"/insights/"+self.definition_id+"/users"
 
-                    s = requests.Session()
-                    s.keep_alive = False
-                    retries = Retry(total=5, backoff_factor=1, status_forcelist=[502, 503, 504])
-                    s.mount('https://', HTTPAdapter(max_retries=retries))
-
-                    headers = {
-                        "Content-Type": "application/json",
-                        "Authorization": "Bearer" + " " + self._token
-                    }
-                    query_url = self.smart_insight_url + '/definitions/' + self.definition_id + '/components/'
-                    #logging.info("URL {}".format(query_url))
-                    r = s.post(url=url, json=body, headers=headers)
-                    r.raise_for_status()
+                    self.__make_post_request(url, body)
                 except:
                     logging.info("User {} can't be invited to channel, make sure the email is associated to an Askdata user".format(follower_email))
         else:
@@ -1379,19 +1147,7 @@ class Insight_Definition:
         }
 
         url = self.smart_insight_url+"/definitions/"+self.definition_id
-
-        s = requests.Session()
-        s.keep_alive = False
-        retries = Retry(total=5, backoff_factor=1, status_forcelist=[502, 503, 504])
-        s.mount('https://', HTTPAdapter(max_retries=retries))
-
-        headers = {
-            "Content-Type": "application/json",
-            "Authorization": "Bearer" + " " + self._token
-        }
-
-        r = s.put(url=url, json=body, headers=headers)
-        r.raise_for_status()
+        r = self.__make_put_request(url, body)
         self.components = r.json()["components"]
 
 
@@ -1399,19 +1155,7 @@ class Insight_Definition:
 
         get_url = self.smart_insight_url+"/definitions/"+self.definition_id+"/card"
 
-        s = requests.Session()
-        s.keep_alive = False
-        retries = Retry(total=5, backoff_factor=1, status_forcelist=[502, 503, 504])
-        s.mount('https://', HTTPAdapter(max_retries=retries))
-
-        headers = {
-            "Content-Type": "application/json",
-            "Authorization": "Bearer" + " " + self._token
-        }
-
-        r = s.get(url=get_url, headers=headers)
-        r.raise_for_status()
-
+        r = self.__make_get_request(get_url)
 
         return r.json()["attachment"]
 
@@ -1435,61 +1179,27 @@ class Insight_Definition:
         r = s.delete(url=query_url, headers=headers)
         r.raise_for_status()
 
-
     def set_on_demand(self, enabled=True):
 
         body = {"enabled":enabled}
 
         url = self.smart_insight_url + "/definitions/" + self.definition_id+ "/intents/status"
-
-        s = requests.Session()
-        s.keep_alive = False
-        retries = Retry(total=5, backoff_factor=1, status_forcelist=[502, 503, 504])
-        s.mount('https://', HTTPAdapter(max_retries=retries))
-
-        headers = {
-            "Content-Type": "application/json",
-            "Authorization": "Bearer" + " " + self._token
-        }
-
-        r = s.put(url=url, json=body, headers=headers)
-        r.raise_for_status()
+        self.__make_put_request(url, body)
 
     def add_on_demand_queries(self, queries):
 
         body = {"userQuery": queries}
 
         url = self.smart_insight_url + "/definitions/" + self.definition_id + "/intents"
-
-        s = requests.Session()
-        s.keep_alive = False
-        retries = Retry(total=5, backoff_factor=1, status_forcelist=[502, 503, 504])
-        s.mount('https://', HTTPAdapter(max_retries=retries))
-
-        headers = {
-            "Content-Type": "application/json",
-            "Authorization": "Bearer" + " " + self._token
-        }
-
-        r = s.put(url=url, json=body, headers=headers)
-        r.raise_for_status()
+        self.__make_put_request(url, body)
 
     def schedule_daily(self, channel_slug, hours, minutues, seconds):
 
         cron = seconds + " " + minutues + " " + hours + " * * *"
 
-        s = requests.Session()
-        s.keep_alive = False
-        retries = Retry(total=5, backoff_factor=1, status_forcelist=[502, 503, 504])
-        s.mount('https://', HTTPAdapter(max_retries=retries))
-
-        headers = {
-            "Content-Type": "application/json",
-            "Authorization": "Bearer" + " " + self._token
-        }
         url = self._base_url_askdata + '/smartfeed/channels?agentId=' + self.agent_id + '&slug=' + channel_slug
-        r = s.get(url=url, headers=headers)
-        r.raise_for_status()
+
+        r = self.__make_get_request(url)
 
         channel_id = r.json()[0]["id"]
 
@@ -1502,19 +1212,7 @@ class Insight_Definition:
             "condition": "always",
             "advancedConditions": None}
 
-
-        s = requests.Session()
-        s.keep_alive = False
-        retries = Retry(total=5, backoff_factor=1, status_forcelist=[502, 503, 504])
-        s.mount('https://', HTTPAdapter(max_retries=retries))
-
-        headers = {
-            "Content-Type": "application/json",
-            "Authorization": "Bearer" + " " + self._token
-        }
-
-        r = s.post(url=url, json=body, headers=headers)
-        r.raise_for_status()
+        self.__make_post_request(url, body)
 
 
     def schedule_monthly(self, channel_slug, day_of_month, hours, minutues, seconds):
@@ -1523,18 +1221,8 @@ class Insight_Definition:
 
         cron = seconds + " " + minutues + " " + hours + day_of_month + " * ?"
 
-        s = requests.Session()
-        s.keep_alive = False
-        retries = Retry(total=5, backoff_factor=1, status_forcelist=[502, 503, 504])
-        s.mount('https://', HTTPAdapter(max_retries=retries))
-
-        headers = {
-            "Content-Type": "application/json",
-            "Authorization": "Bearer" + " " + self._token
-        }
         url = self._base_url_askdata + '/smartfeed/channels?agentId=' + self.agent_id + '&slug=' + channel_slug
-        r = s.get(url=url, headers=headers)
-        r.raise_for_status()
+        r = self.__make_get_request(url)
 
         channel_id = r.json()[0]["id"]
 
@@ -1547,37 +1235,15 @@ class Insight_Definition:
             "condition": "always",
             "advancedConditions": None}
 
-
-        s = requests.Session()
-        s.keep_alive = False
-        retries = Retry(total=5, backoff_factor=1, status_forcelist=[502, 503, 504])
-        s.mount('https://', HTTPAdapter(max_retries=retries))
-
-        headers = {
-            "Content-Type": "application/json",
-            "Authorization": "Bearer" + " " + self._token
-        }
-
-        r = s.post(url=url, json=body, headers=headers)
-        r.raise_for_status()
+        self.__make_post_request(url, body)
 
     def schedule_weekly(self, channel_slug, day_of_week, hours, minutues, seconds):
         """day_of_week: day of the week in format MON, TUE, WED, THU, FRI, SAT, SUN"""
 
         cron = seconds + " " + minutues + " " + hours + " ? * " + day_of_week
 
-        s = requests.Session()
-        s.keep_alive = False
-        retries = Retry(total=5, backoff_factor=1, status_forcelist=[502, 503, 504])
-        s.mount('https://', HTTPAdapter(max_retries=retries))
-
-        headers = {
-            "Content-Type": "application/json",
-            "Authorization": "Bearer" + " " + self._token
-        }
         url = self._base_url_askdata + '/smartfeed/channels?agentId=' + self.agent_id + '&slug=' + channel_slug
-        r = s.get(url=url, headers=headers)
-        r.raise_for_status()
+        r = self.__make_get_request(url)
 
         channel_id = r.json()[0]["id"]
 
@@ -1591,39 +1257,18 @@ class Insight_Definition:
             "condition": "always",
             "advancedConditions": None}
 
-        s = requests.Session()
-        s.keep_alive = False
-        retries = Retry(total=5, backoff_factor=1, status_forcelist=[502, 503, 504])
-        s.mount('https://', HTTPAdapter(max_retries=retries))
-
-        headers = {
-            "Content-Type": "application/json",
-            "Authorization": "Bearer" + " " + self._token
-        }
-
-        r = s.post(url=url, json=body, headers=headers)
-        r.raise_for_status()
+        self.__make_post_request(url, body)
 
     def clone(self, channel_id, card_name="", card_slug=None):
 
         if card_name == "":
             card_name = "Copy of " + self.name
 
-        if card_slug != None:
+        if card_slug is not None:
             try:
                 url = self.smart_insight_url + "/definitions/agent/" + self.agent_id + "/slug/" + card_slug
 
-                s = requests.Session()
-                s.keep_alive = False
-                retries = Retry(total=5, backoff_factor=1, status_forcelist=[502, 503, 504])
-                s.mount('https://', HTTPAdapter(max_retries=retries))
-
-                headers = {
-                    "Content-Type": "application/json",
-                    "Authorization": "Bearer" + " " + self._token
-                }
-                r = s.get(url=url, headers=headers)
-                r.raise_for_status()
+                r = self.__make_get_request(url)
 
                 definition = r.json()
                 insight_definition = Insight_Definition(self._env, self._token, self.agent_slug, definition)
@@ -1632,7 +1277,6 @@ class Insight_Definition:
                 logging.info("{} card not found... creating new one".format(card_slug))
                 #logging.info("{}".format(e.__str__()))
 
-
         url = self.smart_insight_url+"/definitions/"+self.definition_id+"/clone"
         body = {
             "agentId": self.agent_id,
@@ -1641,15 +1285,4 @@ class Insight_Definition:
             "channelId": channel_id
             }
 
-        s = requests.Session()
-        s.keep_alive = False
-        retries = Retry(total=5, backoff_factor=1, status_forcelist=[502, 503, 504])
-        s.mount('https://', HTTPAdapter(max_retries=retries))
-
-        headers = {
-            "Content-Type": "application/json",
-            "Authorization": "Bearer" + " " + self._token
-        }
-
-        r = s.post(url=url, json=body, headers=headers)
-        r.raise_for_status()
\ No newline at end of file
+        self.__make_post_request(url, body)
\ No newline at end of file
