@@ -235,13 +235,49 @@ def read_hubspot_deals(API_KEY,
                         n_days = 7):
     
     
-    from askdata.interations import hubspot_api
+    from askdata.integrations import hubspot_api
     
-    deals_all_fiels = hubspot_api.get_hubspot_deals_all_fiels(API_KEY, n_days)
+    deals_all_fiels = hubspot_api.get_hubspot_deals_all_fields(API_KEY, n_days)
     
     return deals_all_fiels
  
 
     
+## hubspot contact
+
+def read_hubspot_contact(API_KEY,
+                         
+                         #optional input
+                         n_days = 7):
     
+    from askdata.integrations import hubspot_api
+    
+    hubspot_contact = hubspot_api.get_hubspot_contact(API_KEY, n_days)
+    
+    return hubspot_contact
+                         
+           
+        
+## hubspot pipelines
+
+def read_hubspot_pipelines(API_KEY):
+    
+    
+    from askdata.integrations import hubspot_api
+    
+    hubspot_pipelines = hubspot_api.get_hubspot_pipelines(API_KEY)
+    
+    return hubspot_pipelines
+                         
+                         
+    
+## hubspot users
+
+def read_hubspot_users(API_KEY):
+    
+    from askdata.integrations import hubspot_api
+    
+    hubspot_users = hubspot_api.get_hubspot_users(API_KEY)
+    
+    return hubspot_users
     
\ No newline at end of file
