@@ -59,7 +59,8 @@ def response_to_dataframe(response):
 
             for i, values in enumerate(dateRangeValues):
                 for metric, value in zip(metricHeaders, values.get('values')):
-                    if ',' in value or ',' in value:
+                    #if ',' in value or ',' in value:
+                    if ',' in value:
                         dict[metric.get('name')] = float(value)
                     else:
                         dict[metric.get('name')] = int(value)
