@@ -1,14 +1,9 @@
 import requests
 import yaml
 import os
-import pandas as pd
 import logging
 from requests.adapters import HTTPAdapter
 from urllib3.util.retry import Retry
-import numpy as np
-import json as json
-import uuid
-from datetime import datetime
 
 _LOG_FORMAT = "[%(filename)s:%(lineno)s - %(funcName)20s() ] - %(asctime)s --> %(message)s"
 g_logger = logging.getLogger()
